nisrarr-package: nisrarr: Download Data from the NISRA Data Portal

nisrarr-packageR Documentation

nisrarr: Download Data from the NISRA Data Portal

Description

Download data from the Northern Ireland Statistics and Research Agency (NISRA) data portal, accessed at https://data.nisra.gov.uk. NISRA is a government agency and the principal source of official statistics and social research on Northern Ireland.

Author(s)

Maintainer: Mark Paulin paulin.mark@googlemail.com [copyright holder]

See Also

Useful links:


nisrarr documentation built on June 8, 2025, 11:15 a.m.