| nisrarr-package | R Documentation |
Download data from the Northern Ireland Statistics and Research Agency (NISRA) data portal, accessed at https://data.nisra.gov.uk. NISRA is a government agency and the principal source of official statistics and social research on Northern Ireland.
Maintainer: Mark Paulin paulin.mark@googlemail.com [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.